#
# spec file for package nwg-dock-hyprland
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023-2024 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nwg-dock-hyprland
Version:        0.1.9
Release:        1.1
Summary:        Hyprland application dock
License:        MIT
URL:            https://github.com/nwg-piotr/nwg-dock-hyprland
Source0:        https://codeload.github.com/nwg-piotr/nwg-dock-hyprland/tar.gz/refs/tags/v%{version}#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  go >= 1.22
BuildRequires:  golang-packaging
BuildRequires:  zstd
BuildRequires:  pkgconfig(gtk-layer-shell-0)

%description
Configurable (w/ command line arguments and css) dock, written in Go, aimed
exclusively at the Hyprland Wayland compositor. It features pinned buttons,
client buttons and the launcher button.

%prep
%autosetup -p1 -a1

%build
## Note build takes around 10 minutes, so be patient as there is no output!
go build \
   -mod=vendor \
   -buildmode=pie

%install
install -d -m 0755 %{buildroot}%{_bindir} %{buildroot}%{_datadir}/%{name}
install -m 0755 %{name} %{buildroot}%{_bindir}/%{name}
install -m 0644 config/style.css %{buildroot}%{_datadir}/%{name}/style.css

%files
%license LICENSE
%{_bindir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/style.css

%changelog
* Wed Jun 12 2024 malcolmlewis@opensuse.org
- Updated to version 0.1.9:
  + Fixed crash on icons missing from GTK theme,
    (gh#nwg-piotr/nwg-dock-hyprland#25).
  + Fixed XDG_DATA_HOME detection,
    (gh#nwg-piotr/nwg-dock-hyprland#36 and
    gh#nwg-piotr/nwg-dock-hyprlandcloses #35).
  + Added setting namespace for gtk-layer-shell,
    (gh#nwg-piotr/nwg-dock-hyprland#37).
  + Fixed mapping output->Gdk.Monitor on gtk3-1:3.24.42.
- Changes from version 0.1.8:
  + Get ready for Hyprland socket files moved to
    $XDG_RUNTIME_DIR/hypr, (gh#nwg-piotr/nwg-dock-hyprland#30).
  + While searching .desktop files, first look for exact
    'class.desktop' file, (gh#nwg-piotr/nwg-dock-hyprland#31).
- Changes from version 0.1.7:
  + Prevent crash on image not found,
    (gh#nwg-piotr/nwg-dock-hyprland#25 and
    gh#nwg-piotr/nwg-dock-hyprland#24).
  + Use different lock files for various users (ported from
    nwg-dock).
- Changes from version 0.1.6:
  + Fixed nil pointer dereference while creating the fallback icon,
    (gh#nwg-piotr/nwg-dock-hyprland#24).
- Changes from version 0.1.5:
  + Added dispatch bringactivetotop after dispatch focuswindow,
    (gh#nwg-piotr/nwg-dock-hyprland#14).
  + Updated dependencies: gotk3, gotk3-layershell, logrus.
  + Added -ico string argument, to specify name or full path to an
    alternative launcher ICOn,
    (gh#nwg-piotr/nwg-dock-hyprland#15 and
    gh#nwg-piotr/nwg-dock-hyprland#17).
  + Added support for apps on the special workspace,
    (gh#nwg-piotr/nwg-dock-hyprland#13).
  + Fixed searching icons in org.*.desktop files.
- Changes from version 0.1.4:
  + Split appName string by " ", use the 1st part while searching
    the icon name, (gh#nwg-piotr/nwg-dock-hyprland#11).
  + Do not force use of the overlay layer when -d (autohide)
    argument used, (gh#nwg-piotr/nwg-dock-hyprland#12).
- Update build requires on go >= 1.22.
* Mon Jul 17 2023 malcolmlewis@opensuse.org
- Initial build at version 0.1.3.
